@@ -5,8 +5,8 @@ using DifferentiationInterface: DifferentiationInterface, Constant
 using FastClosures: @closure
 using LinearAlgebra: LinearAlgebra, I, diagind
 using NonlinearSolveBase: NonlinearSolveBase, AbstractNonlinearTerminationMode,
-                          AbstractSafeNonlinearTerminationMode,
-                          AbstractSafeBestNonlinearTerminationMode
+    AbstractSafeNonlinearTerminationMode,
+    AbstractSafeBestNonlinearTerminationMode
 using SciMLBase: SciMLBase, ReturnCode
 using StaticArraysCore: StaticArray, SArray, SMatrix, SVector
 
@@ -59,7 +59,7 @@ function check_termination(cache, fx, x, xo, _, ::AbstractSafeNonlinearTerminati
 end
 function check_termination(
         cache, fx, x, xo, prob, ::AbstractSafeBestNonlinearTerminationMode
-)
+    )
     if cache(fx, x, xo)
         x = cache.u
         fx = NLBUtils.evaluate_f!!(prob, fx, x)
@@ -87,12 +87,18 @@ end
 function prepare_jacobian(prob, autodiff, fx, x)
     SciMLBase.has_jac(prob.f) && return AnalyticJacobian()
     if SciMLBase.isinplace(prob.f)
-        return DIExtras(DI.prepare_jacobian(
-            prob.f, fx, autodiff, x, Constant(prob.p), strict = Val(false)))
+        return DIExtras(
+            DI.prepare_jacobian(
+                prob.f, fx, autodiff, x, Constant(prob.p), strict = Val(false)
+            )
+        )
     else
         x isa SArray && return DINoPreparation()
-        return DIExtras(DI.prepare_jacobian(
-            prob.f, autodiff, x, Constant(prob.p), strict = Val(false)))
+        return DIExtras(
+            DI.prepare_jacobian(
+                prob.f, autodiff, x, Constant(prob.p), strict = Val(false)
+            )
+        )
     end
 end
 
@@ -166,8 +172,10 @@ function compute_hvvp(prob, autodiff, _, x::Number, dir::Number)
 end
 function compute_hvvp(prob, autodiff, fx, x, dir)
     jvp_fn = if SciMLBase.isinplace(prob)
-        @closure (u,
-            p) -> begin
+        @closure (
+            u,
+            p,
+        ) -> begin
             du = NLBUtils.safe_similar(fx, promote_type(eltype(fx), eltype(u)))
             return only(DI.pushforward(prob.f, du, autodiff, u, (dir,), Constant(p)))
         end
@@ -179,7 +187,7 @@ end
 
 function nonlinear_solution_new_alg(
         sol::SciMLBase.NonlinearSolution{T, N, uType, R, P, A, O, uType2, S, Tr}, alg
-) where {T, N, uType, R, P, A, O, uType2, S, Tr}
+    ) where {T, N, uType, R, P, A, O, uType2, S, Tr}
     return SciMLBase.NonlinearSolution{T, N, uType, R, P, typeof(alg), O, uType2, S, Tr}(
         sol.u, sol.resid, sol.prob, alg, sol.retcode, sol.original, sol.left, sol.right,
         sol.stats, sol.trace
